StandardDialogsLocalizations class

Inheritance
  • Object
  • SimpleLocalizations
  • StandardDialogsLocalizations

Constructors

StandardDialogsLocalizations(Locale locale)

Properties

currentLocale ↔ Locale
Current location loaded
getter/setter pairinherited
customValues → Map<String, Map<dynamic, String>>?
Custom values, used to modify certain values, this property should only be used in custom package locations that use internationalization.
no setterinherited
defaultLocale → Locale
If your device location is not supported, this will be the default location to use
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
localizedValues → Map<String, Map<dynamic, String>>
Message values to be used by your app for all supported locations.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suportedLocales → Iterable<Locale>
Locations supported by your app
no setteroverride

Methods

getLocalizedValue(dynamic localizedName) → String
Function to get message to use
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](dynamic message) → String
Operator to get message to use
inherited

Static Methods

of(BuildContext context) → StandardDialogsLocalizations
Get current location instance
override