StandardDialogsLocalizationsDelegate class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type
The type of the object returned by the load method, T by default.
no setterinherited

Methods

initializeLocalization(Locale currentLocale) → StandardDialogsLocalizations
Initialize the localization class
override
isSupported(Locale locale) → bool
Whether resources for the given locale can be loaded by this delegate.
inherited
load(Locale locale) → Future<StandardDialogsLocalizations>
Start loading the resources for locale. The returned future completes when the resources have finished loading.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldReload(covariant dynamic old) → bool
Returns true if the resources for this delegate should be loaded again by calling the load method.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited