ChoiceDialog<T> class abstract

Abstract widget used to set up the choices dialog

Inheritance
Implementers

Constructors

ChoiceDialog(Key? key, Widget title, Widget? content, List<DialogChoice<T>> choices, List<DialogAction<T>> actions)
const

Properties

actions → List<DialogAction<T>>
final
choices → List<DialogChoice<T>>
final
content → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → Widget
final

Methods

buildActions(BuildContext context, List<DialogChoice<T>> selectedChoices) → List<Widget>
buildChoicesDetail(BuildContext context, DialogChoice choice) → Widget
buildChoicesList(BuildContext context, List<DialogChoice<T>> selectedChoices, Function setValue) → List<Widget>
buildDescription(BuildContext context, Widget? description) → Widget?
buildTextWithStyle(Widget widget, TextStyle textStyle) → Widget
buildTitle(BuildContext context, Widget title) → Widget
cancelDialog(BuildContext context) → dynamic
confirmDialog(BuildContext context, List<DialogChoice<T>>? selectedChoices) → dynamic
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited